#!/bin/bash

DBDIR=/usr/local/pgsql
tooltar=patch-report.tar.gz

cd $(dirname $0)

: "before processing" && {
	echo "$(date '+%Y.%m.%d %H:%M:%S'): Start processing"
	echo
	df -h
	echo

	trap '/bin/rm -f custom_function.sql' 1 2 3 15

	if ! [ -f $tooltar ]; then
		echo "Error. $tooltar does not exists!"
		echo "abort."
		exit 1
	fi

	which systemctl > /dev/null 2>&1
	if [ $? -eq 0 ]; then
		systemctl stop iccpasrvnew.service
	else
		/etc/rc.d/init.d/iccsrvnew stop
	fi
	sync; sync; sync
	sleep 10

	tar xzf $tooltar
}

: "main routine" && {
	echo "$(date '+%Y.%m.%d %H:%M:%S'): Start create calendar"
	for loop in $(seq 0 2192); do
		ymd=$(date -d "2020-01-01 $loop day" "+%Y-%m-%d")
		$DBDIR/bin/psql -U postgres -d iccpadb2 -q <<-EOF 2> /dev/null
			insert into pasokon.pa_calendar
			select '$ymd',
			       extract(dow from timestamp '$ymd'),
			       case extract(dow from timestamp '$ymd') when 1 then 1
			                                               when 2 then 1
			                                               when 3 then 1
			                                               when 4 then 1
			                                               when 5 then 1
			                                               when 6 then 0
			                                               when 0 then 0
			       end
			;
			\q
		EOF
	done
	echo "$(date '+%Y.%m.%d %H:%M:%S'): End   create calendar"
	echo

	echo "$(date '+%Y.%m.%d %H:%M:%S'): Start create report"
	$DBDIR/bin/psql -U postgres -d iccpadb2 <<-EOF
		-- create function, tables
		\i custom_function.sql

		-- create report tables
		insert into pasokon.xx_power_on
		select * from pasokon.pa_power_on
		 where power_time > '2020-01-01'
		 order by id;

		drop table pasokon.xx_power_on;
		drop function pasokon."xx_UPDATE_START_DOWN"();

		--
		drop table pasokon.xx_process_log;
		drop function pasokon."xx_pa_process_log_ins"();

		\q
	EOF
	echo "$(date '+%Y.%m.%d %H:%M:%S'): End   create report"
	echo
}

: "after processing" && {
	which systemctl > /dev/null 2>&1
	if [ $? -eq 0 ]; then
		systemctl start iccpasrvnew.service
		sleep 5
		systemctl status iccpasrvnew.service
	else
		/etc/rc.d/init.d/iccsrvnew start
		sleep 5
		/etc/rc.d/init.d/iccsrvnew status
	fi

	echo "$(date '+%Y.%m.%d %H:%M:%S'): Finish processing"
}

/bin/rm -f $tooltar custom_function.sql $0
